package exported
import "github.com/AzureAD/microsoft-authentication-library-for-go/apps/internal/exported"
package exported contains internal types that are re-exported from a public package
Index ¶
Types ¶
type AssertionRequestOptions ¶
type AssertionRequestOptions struct {
// ClientID identifies the application for which an assertion is requested. Used as the assertion's "iss" and "sub" claims.
ClientID string
// TokenEndpoint is the intended token endpoint. Used as the assertion's "aud" claim.
TokenEndpoint string
}
AssertionRequestOptions has information required to generate a client assertion
type TokenProviderParameters ¶
type TokenProviderParameters struct {
// Claims contains any additional claims requested for the token
Claims string
// CorrelationID of the authentication request
CorrelationID string
// Scopes requested for the token
Scopes []string
// TenantID identifies the tenant in which to authenticate
TenantID string
}
TokenProviderParameters is the authentication parameters passed to token providers
type TokenProviderResult ¶
type TokenProviderResult struct {
// AccessToken is the requested token
AccessToken string
// ExpiresInSeconds is the lifetime of the token in seconds
ExpiresInSeconds int
// RefreshInSeconds indicates the suggested time to refresh the token, if any
RefreshInSeconds int
}
TokenProviderResult is the authentication result returned by custom token providers
Source Files ¶
- Version
- v1.6.0 (latest)
- Published
- Nov 5, 2025
- Platform
- linux/amd64
- Last checked
- 4 months ago –
Tools for package owners.